/* -*- mode: c++; indent-tabs-mode: nil; -*-
 *
 * This file is part of the Mango recipe management distribution.
 * Copyright (c) 2000-2003, Roland Jesse
 * All rights reserved.
 *
 * For license and copyright information see the file COPYRIGHT or 
 * <http://www.opensource.org/licenses/bsd-license.html>.
 *
 * $Id: resources.h,v 1.22 2003/10/30 14:53:05 rjesse Exp $
 */
 
#ifndef RESOURCES_HPP
#define RESOURCES_HPP

#include <qstring.h>

/*!
  \file resources.h

  Global definitions and defines.

  The MANGO_FILE_VERSION_* defines can be used for changes in Mango's
  native file format. History of versions:

  - Mango 0.16 introduced file format version 1.
  - Mango 0.26 introduced file format version 2:
    * Multiple images instead of just one per recipe.
    * Range and unit of a recipe's yield value.
    * Quantity and range for ingredients.
    * Instead of an overall recipe's cooking time: list of preparation
      steps with associated time stamps.
    * Weight Watchers points for recipes and ingredients.
    * Free text remarks for each recipe on a per person basis.
*/

/*! Lowest supported version number of Mango's native file format. */
#define MANGO_FILE_VERSION_LOWEST 1
/*! Current version number of Mango's native file format. */
#define MANGO_FILE_VERSION_CURRENT 2

/*! Defines %Mango's major version number. */
#define MANGO_MAJOR_VERSION 0
/*! Defines %Mango's release version number. */
#define MANGO_MINOR_VERSION 27
/*! Defines %Mango's patchlevel version number. */
#define MANGO_MICRO_VERSION 0
/*!  
  The integer representation of the program version is a six digits
  number: two for the major version, two for release, and two for
  minor version.
*/
#define MANGO_VERSION $MANGO_MAJOR_VERSION$MANGO_MINOR_VERSION$MANGO_MICRO_VERSION
/*! Defines a string representation of %Mango's version. */
#define MANGO_VERSION_STRING "0.27 (Bad Plus)"

/*!
  The default string shown in the status bar.
  \sa STATUS_NOTICE_DURATION
*/
const QString STATUS_DEFAULT( QObject::tr( "Ready"));

/*! 
  Time in milliseconds, a notice stays active in the statusbar. 
  \sa STATUS_DEFAULT
*/
const int STATUS_NOTICE_DURATION = 2000;

#endif // RESOURCES_HPP
